<?php

namespace app\models;

use Yii;
use yii\db\ActiveRecord;
use yii\behaviors\TimestampBehavior; 
use yii\behaviors\BlameableBehavior;

/**
 * This is the model class for table "comment".
 *
 * @property integer $id
 * @property integer $user_id
 * @property integer $page_id
 * @property string $comment
 * @property string $date_entered
 *
 * @property Page $page
 * @property User $user
 */
class Comment extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'comment';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            // Required attributes (by the user): 
            [['comment'], 'required'],
            // Must be in related models (tables):
            [['user_id'], 'exist', 'targetClass'=>'User', 'targetAttribute'=>'id'],
            [['page_id'], 'exist', 'targetClass'=>'Page', 'targetAttribute'=>'id'],
            // Strip tags from the comments:
            [['comment'], 'filter', 'filter'=>'strip_tags']
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'user_id' => 'User ID',
            'page_id' => 'Page ID',
            'comment' => 'Comment',
            'date_entered' => 'Date Entered',
        ];
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'attributes' => [
                    ActiveRecord::EVENT_BEFORE_INSERT => ['date_entered']
                ],
            ],
            [
                'class' => BlameableBehavior::className(),
                'createdByAttribute' => 'user_id'
            ],
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPage()
    {
        return $this->hasOne(Page::className(), ['id' => 'page_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUser()
    {
        return $this->hasOne(User::className(), ['id' => 'user_id']);
    }
}
