<?php

namespace app\models;

use Yii;
use yii\db\ActiveRecord;
use yii\behaviors\TimestampBehavior; 
use yii\behaviors\BlameableBehavior;

/**
 * This is the model class for table "file".
 *
 * @property integer $id
 * @property integer $user_id
 * @property string $name
 * @property string $type
 * @property integer $size
 * @property string $description
 * @property string $date_entered
 * @property string $date_updated
 *
 * @property User $user
 * @property PageHasFile[] $pageHasFiles
 * @property Page[] $pages
 */
class File extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'file';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            // name, type, size are required (sort of come from the user) 
            [['name', 'type', 'size'], 'required'],
            
            // User must exist in the related table:
            [['user_id'], 'exist', 'targetClass'=>'User', 'targetAttribute'=>'id'],

            // Size must be an integer:
            [['size'], 'integer'],

            // description is optional; must be filtered
            // and set to NULL when empty:
            [['description'], 'filter', 'filter' => 'strip_tags'], [['description'], 'default', 'value' => NULL],
            
            // Maximum length on the name:
            [['name'], 'string', 'max' => 80],
            
            // Type must be of an appropriate kind:
            [['type'], 'filter', 'filter' => 'validateType'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'user_id' => 'Uploaded By',
            'name' => 'File Name',
            'type' => 'File Type',
            'size' => 'File Size',
            'description' => 'Description',
            'date_entered' => 'Date Entered',
            'date_updated' => 'Date Updated',
        ];
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'attributes' => [
                    ActiveRecord::EVENT_BEFORE_INSERT => ['date_entered', 
                        'date_updated'],
                    ActiveRecord::EVENT_BEFORE_UPDATE => ['date_updated'],
                ],
            ],
            [
                'class' => BlameableBehavior::className(),
                'createdByAttribute' => 'user_id'
            ],
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUser()
    {
        return $this->hasOne(User::className(), ['id' => 'user_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPageHasFiles()
    {
        return $this->hasMany(PageHasFile::className(), ['file_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPages()
    {
        return $this->hasMany(Page::className(), ['id' => 'page_id'])->viaTable('page_has_file', ['file_id' => 'id']);
    }
}
