<?php

namespace app\models;

use Yii;
use yii\db\ActiveRecord;
use yii\behaviors\TimestampBehavior; 
use yii\behaviors\BlameableBehavior;

/**
 * This is the model class for table "user".
 *
 * @property integer $id
 * @property string $username
 * @property string $email
 * @property string $pass
 * @property string $type
 * @property string $date_entered
 *
 * @property Comment[] $comments
 * @property File[] $files
 * @property Page[] $pages
 */
class User extends \yii\db\ActiveRecord
{
    
    public $passCompare; // Needed for registration! 

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'user';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            // Required fields when registering: 
            [['username', 'email', 'pass'], 'required', 'on'=>'register'],

            // Required fields when logging in:
            [['username', 'pass'], 'required', 'on'=>'login'],
            
            // Username must be unique and less than 45 characters:
            [['email', 'username'], 'unique'],
            [['username'], 'string', 'max' => 45],
            
            // Email address must also be unique (see above), an email address, 
            // and less than 60 characters:
            [['email'], 'email'],
            [['email'], 'string', 'max' => 60],
            
            // Password must match a regular expression:
            [['pass'], 'match', 'pattern'=>'/^[a-z0-9_-]{6,20}$/i'],

            // Password must match the comparison:
            [['pass'], 'compare', 'compareAttribute'=>'passCompare', 'on'=>'register'], 
            
            // Set the type to "public" by default:     
            [['type'], 'default', 'value'=>'public'], 

            // Type must also be one of three values:
            [['type'], 'in', 'range'=>['public', 'author', 'admin']],

        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'username' => 'Username',
            'email' => 'Email',
            'pass' => 'Password',
            'type' => 'Type',
            'date_entered' => 'Date Entered',
            'passCompare' => 'Password Confirmation'
        ];
    }

    public function behaviors()
    {
        return [[
            'class' => TimestampBehavior::className(),
            'attributes' => [
                ActiveRecord::EVENT_BEFORE_INSERT => ['date_entered']
            ]],
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getComments()
    {
        return $this->hasMany(Comment::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getFiles()
    {
        return $this->hasMany(File::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getPages()
    {
        return $this->hasMany(Page::className(), ['user_id' => 'id']);
    }
}
